@@ -1,7 +1,8 @@
 #! /bin/false
+
 # vim: set autoindent shiftwidth=4 tabstop=4:
 
-# Conversion routines for ISO-8859-3.
+# Conversion routines for ISO-8859-1.
 # Copyright (C) 2002-2026 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
@@ -18,273 +19,14 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-package Locale::RecodeData::ISO_8859_3;
+package Locale::RecodeData::ISO_8859_1;
 
 use strict;
 
 require Locale::RecodeData;
 use base qw(Locale::RecodeData);
 
-my @to_ucs4 = (
-    0x0000,
-    0x0001,
-    0x0002,
-    0x0003,
-    0x0004,
-    0x0005,
-    0x0006,
-    0x0007,
-    0x0008,
-    0x0009,
-    0x000a,
-    0x000b,
-    0x000c,
-    0x000d,
-    0x000e,
-    0x000f,
-    0x0010,
-    0x0011,
-    0x0012,
-    0x0013,
-    0x0014,
-    0x0015,
-    0x0016,
-    0x0017,
-    0x0018,
-    0x0019,
-    0x001a,
-    0x001b,
-    0x001c,
-    0x001d,
-    0x001e,
-    0x001f,
-    0x0020,
-    0x0021,
-    0x0022,
-    0x0023,
-    0x0024,
-    0x0025,
-    0x0026,
-    0x0027,
-    0x0028,
-    0x0029,
-    0x002a,
-    0x002b,
-    0x002c,
-    0x002d,
-    0x002e,
-    0x002f,
-    0x0030,
-    0x0031,
-    0x0032,
-    0x0033,
-    0x0034,
-    0x0035,
-    0x0036,
-    0x0037,
-    0x0038,
-    0x0039,
-    0x003a,
-    0x003b,
-    0x003c,
-    0x003d,
-    0x003e,
-    0x003f,
-    0x0040,
-    0x0041,
-    0x0042,
-    0x0043,
-    0x0044,
-    0x0045,
-    0x0046,
-    0x0047,
-    0x0048,
-    0x0049,
-    0x004a,
-    0x004b,
-    0x004c,
-    0x004d,
-    0x004e,
-    0x004f,
-    0x0050,
-    0x0051,
-    0x0052,
-    0x0053,
-    0x0054,
-    0x0055,
-    0x0056,
-    0x0057,
-    0x0058,
-    0x0059,
-    0x005a,
-    0x005b,
-    0x005c,
-    0x005d,
-    0x005e,
-    0x005f,
-    0x0060,
-    0x0061,
-    0x0062,
-    0x0063,
-    0x0064,
-    0x0065,
-    0x0066,
-    0x0067,
-    0x0068,
-    0x0069,
-    0x006a,
-    0x006b,
-    0x006c,
-    0x006d,
-    0x006e,
-    0x006f,
-    0x0070,
-    0x0071,
-    0x0072,
-    0x0073,
-    0x0074,
-    0x0075,
-    0x0076,
-    0x0077,
-    0x0078,
-    0x0079,
-    0x007a,
-    0x007b,
-    0x007c,
-    0x007d,
-    0x007e,
-    0x007f,
-    0x0080,
-    0x0081,
-    0x0082,
-    0x0083,
-    0x0084,
-    0x0085,
-    0x0086,
-    0x0087,
-    0x0088,
-    0x0089,
-    0x008a,
-    0x008b,
-    0x008c,
-    0x008d,
-    0x008e,
-    0x008f,
-    0x0090,
-    0x0091,
-    0x0092,
-    0x0093,
-    0x0094,
-    0x0095,
-    0x0096,
-    0x0097,
-    0x0098,
-    0x0099,
-    0x009a,
-    0x009b,
-    0x009c,
-    0x009d,
-    0x009e,
-    0x009f,
-    0x00a0,
-    0x0126,
-    0x02d8,
-    0x00a3,
-    0x00a4,
-    0xfffd,
-    0x0124,
-    0x00a7,
-    0x00a8,
-    0x0130,
-    0x015e,
-    0x011e,
-    0x0134,
-    0x00ad,
-    0xfffd,
-    0x017b,
-    0x00b0,
-    0x0127,
-    0x00b2,
-    0x00b3,
-    0x00b4,
-    0x00b5,
-    0x0125,
-    0x00b7,
-    0x00b8,
-    0x0131,
-    0x015f,
-    0x011f,
-    0x0135,
-    0x00bd,
-    0xfffd,
-    0x017c,
-    0x00c0,
-    0x00c1,
-    0x00c2,
-    0xfffd,
-    0x00c4,
-    0x010a,
-    0x0108,
-    0x00c7,
-    0x00c8,
-    0x00c9,
-    0x00ca,
-    0x00cb,
-    0x00cc,
-    0x00cd,
-    0x00ce,
-    0x00cf,
-    0xfffd,
-    0x00d1,
-    0x00d2,
-    0x00d3,
-    0x00d4,
-    0x0120,
-    0x00d6,
-    0x00d7,
-    0x011c,
-    0x00d9,
-    0x00da,
-    0x00db,
-    0x00dc,
-    0x016c,
-    0x015c,
-    0x00df,
-    0x00e0,
-    0x00e1,
-    0x00e2,
-    0xfffd,
-    0x00e4,
-    0x010b,
-    0x0109,
-    0x00e7,
-    0x00e8,
-    0x00e9,
-    0x00ea,
-    0x00eb,
-    0x00ec,
-    0x00ed,
-    0x00ee,
-    0x00ef,
-    0xfffd,
-    0x00f1,
-    0x00f2,
-    0x00f3,
-    0x00f4,
-    0x0121,
-    0x00f6,
-    0x00f7,
-    0x011d,
-    0x00f9,
-    0x00fa,
-    0x00fb,
-    0x00fc,
-    0x016d,
-    0x015d,
-    0x02d9,
-);
-
-my @to_utf8 = (
+use constant TO_UTF8 => [
     "\x00",
     "\x01",
     "\x02",
@@ -446,44 +188,44 @@ my @to_utf8 = (
     "\xc2\x9e",
     "\xc2\x9f",
     "\xc2\xa0",
-    "\xc4\xa6",
-    "\xcb\x98",
+    "\xc2\xa1",
+    "\xc2\xa2",
     "\xc2\xa3",
     "\xc2\xa4",
-    "\xef\xbf\xbd",
-    "\xc4\xa4",
+    "\xc2\xa5",
+    "\xc2\xa6",
     "\xc2\xa7",
     "\xc2\xa8",
-    "\xc4\xb0",
-    "\xc5\x9e",
-    "\xc4\x9e",
-    "\xc4\xb4",
+    "\xc2\xa9",
+    "\xc2\xaa",
+    "\xc2\xab",
+    "\xc2\xac",
     "\xc2\xad",
-    "\xef\xbf\xbd",
-    "\xc5\xbb",
+    "\xc2\xae",
+    "\xc2\xaf",
     "\xc2\xb0",
-    "\xc4\xa7",
+    "\xc2\xb1",
     "\xc2\xb2",
     "\xc2\xb3",
     "\xc2\xb4",
     "\xc2\xb5",
-    "\xc4\xa5",
+    "\xc2\xb6",
     "\xc2\xb7",
     "\xc2\xb8",
-    "\xc4\xb1",
-    "\xc5\x9f",
-    "\xc4\x9f",
-    "\xc4\xb5",
+    "\xc2\xb9",
+    "\xc2\xba",
+    "\xc2\xbb",
+    "\xc2\xbc",
     "\xc2\xbd",
-    "\xef\xbf\xbd",
-    "\xc5\xbc",
+    "\xc2\xbe",
+    "\xc2\xbf",
     "\xc3\x80",
     "\xc3\x81",
     "\xc3\x82",
-    "\xef\xbf\xbd",
+    "\xc3\x83",
     "\xc3\x84",
-    "\xc4\x8a",
-    "\xc4\x88",
+    "\xc3\x85",
+    "\xc3\x86",
     "\xc3\x87",
     "\xc3\x88",
     "\xc3\x89",
@@ -493,29 +235,29 @@ my @to_utf8 = (
     "\xc3\x8d",
     "\xc3\x8e",
     "\xc3\x8f",
-    "\xef\xbf\xbd",
+    "\xc3\x90",
     "\xc3\x91",
     "\xc3\x92",
     "\xc3\x93",
     "\xc3\x94",
-    "\xc4\xa0",
+    "\xc3\x95",
     "\xc3\x96",
     "\xc3\x97",
-    "\xc4\x9c",
+    "\xc3\x98",
     "\xc3\x99",
     "\xc3\x9a",
     "\xc3\x9b",
     "\xc3\x9c",
-    "\xc5\xac",
-    "\xc5\x9c",
+    "\xc3\x9d",
+    "\xc3\x9e",
     "\xc3\x9f",
     "\xc3\xa0",
     "\xc3\xa1",
     "\xc3\xa2",
-    "\xef\xbf\xbd",
+    "\xc3\xa3",
     "\xc3\xa4",
-    "\xc4\x8b",
-    "\xc4\x89",
+    "\xc3\xa5",
+    "\xc3\xa6",
     "\xc3\xa7",
     "\xc3\xa8",
     "\xc3\xa9",
@@ -525,290 +267,35 @@ my @to_utf8 = (
     "\xc3\xad",
     "\xc3\xae",
     "\xc3\xaf",
-    "\xef\xbf\xbd",
+    "\xc3\xb0",
     "\xc3\xb1",
     "\xc3\xb2",
     "\xc3\xb3",
     "\xc3\xb4",
-    "\xc4\xa1",
+    "\xc3\xb5",
     "\xc3\xb6",
     "\xc3\xb7",
-    "\xc4\x9d",
+    "\xc3\xb8",
     "\xc3\xb9",
     "\xc3\xba",
     "\xc3\xbb",
     "\xc3\xbc",
-    "\xc5\xad",
-    "\xc5\x9d",
-    "\xcb\x99",
-);
-
-my %from_ucs4 = (
-    0x00000000 => "\x00",
-    0x00000001 => "\x01",
-    0x00000002 => "\x02",
-    0x00000003 => "\x03",
-    0x00000004 => "\x04",
-    0x00000005 => "\x05",
-    0x00000006 => "\x06",
-    0x00000007 => "\x07",
-    0x00000008 => "\x08",
-    0x00000009 => "\x09",
-    0x0000000a => "\x0a",
-    0x0000000b => "\x0b",
-    0x0000000c => "\x0c",
-    0x0000000d => "\x0d",
-    0x0000000e => "\x0e",
-    0x0000000f => "\x0f",
-    0x00000010 => "\x10",
-    0x00000011 => "\x11",
-    0x00000012 => "\x12",
-    0x00000013 => "\x13",
-    0x00000014 => "\x14",
-    0x00000015 => "\x15",
-    0x00000016 => "\x16",
-    0x00000017 => "\x17",
-    0x00000018 => "\x18",
-    0x00000019 => "\x19",
-    0x0000001a => "\x1a",
-    0x0000001b => "\x1b",
-    0x0000001c => "\x1c",
-    0x0000001d => "\x1d",
-    0x0000001e => "\x1e",
-    0x0000001f => "\x1f",
-    0x00000020 => "\x20",
-    0x00000021 => "\x21",
-    0x00000022 => "\x22",
-    0x00000023 => "\x23",
-    0x00000024 => "\x24",
-    0x00000025 => "\x25",
-    0x00000026 => "\x26",
-    0x00000027 => "\x27",
-    0x00000028 => "\x28",
-    0x00000029 => "\x29",
-    0x0000002a => "\x2a",
-    0x0000002b => "\x2b",
-    0x0000002c => "\x2c",
-    0x0000002d => "\x2d",
-    0x0000002e => "\x2e",
-    0x0000002f => "\x2f",
-    0x00000030 => "\x30",
-    0x00000031 => "\x31",
-    0x00000032 => "\x32",
-    0x00000033 => "\x33",
-    0x00000034 => "\x34",
-    0x00000035 => "\x35",
-    0x00000036 => "\x36",
-    0x00000037 => "\x37",
-    0x00000038 => "\x38",
-    0x00000039 => "\x39",
-    0x0000003a => "\x3a",
-    0x0000003b => "\x3b",
-    0x0000003c => "\x3c",
-    0x0000003d => "\x3d",
-    0x0000003e => "\x3e",
-    0x0000003f => "\x3f",
-    0x00000040 => "\x40",
-    0x00000041 => "\x41",
-    0x00000042 => "\x42",
-    0x00000043 => "\x43",
-    0x00000044 => "\x44",
-    0x00000045 => "\x45",
-    0x00000046 => "\x46",
-    0x00000047 => "\x47",
-    0x00000048 => "\x48",
-    0x00000049 => "\x49",
-    0x0000004a => "\x4a",
-    0x0000004b => "\x4b",
-    0x0000004c => "\x4c",
-    0x0000004d => "\x4d",
-    0x0000004e => "\x4e",
-    0x0000004f => "\x4f",
-    0x00000050 => "\x50",
-    0x00000051 => "\x51",
-    0x00000052 => "\x52",
-    0x00000053 => "\x53",
-    0x00000054 => "\x54",
-    0x00000055 => "\x55",
-    0x00000056 => "\x56",
-    0x00000057 => "\x57",
-    0x00000058 => "\x58",
-    0x00000059 => "\x59",
-    0x0000005a => "\x5a",
-    0x0000005b => "\x5b",
-    0x0000005c => "\x5c",
-    0x0000005d => "\x5d",
-    0x0000005e => "\x5e",
-    0x0000005f => "\x5f",
-    0x00000060 => "\x60",
-    0x00000061 => "\x61",
-    0x00000062 => "\x62",
-    0x00000063 => "\x63",
-    0x00000064 => "\x64",
-    0x00000065 => "\x65",
-    0x00000066 => "\x66",
-    0x00000067 => "\x67",
-    0x00000068 => "\x68",
-    0x00000069 => "\x69",
-    0x0000006a => "\x6a",
-    0x0000006b => "\x6b",
-    0x0000006c => "\x6c",
-    0x0000006d => "\x6d",
-    0x0000006e => "\x6e",
-    0x0000006f => "\x6f",
-    0x00000070 => "\x70",
-    0x00000071 => "\x71",
-    0x00000072 => "\x72",
-    0x00000073 => "\x73",
-    0x00000074 => "\x74",
-    0x00000075 => "\x75",
-    0x00000076 => "\x76",
-    0x00000077 => "\x77",
-    0x00000078 => "\x78",
-    0x00000079 => "\x79",
-    0x0000007a => "\x7a",
-    0x0000007b => "\x7b",
-    0x0000007c => "\x7c",
-    0x0000007d => "\x7d",
-    0x0000007e => "\x7e",
-    0x0000007f => "\x7f",
-    0x00000080 => "\x80",
-    0x00000081 => "\x81",
-    0x00000082 => "\x82",
-    0x00000083 => "\x83",
-    0x00000084 => "\x84",
-    0x00000085 => "\x85",
-    0x00000086 => "\x86",
-    0x00000087 => "\x87",
-    0x00000088 => "\x88",
-    0x00000089 => "\x89",
-    0x0000008a => "\x8a",
-    0x0000008b => "\x8b",
-    0x0000008c => "\x8c",
-    0x0000008d => "\x8d",
-    0x0000008e => "\x8e",
-    0x0000008f => "\x8f",
-    0x00000090 => "\x90",
-    0x00000091 => "\x91",
-    0x00000092 => "\x92",
-    0x00000093 => "\x93",
-    0x00000094 => "\x94",
-    0x00000095 => "\x95",
-    0x00000096 => "\x96",
-    0x00000097 => "\x97",
-    0x00000098 => "\x98",
-    0x00000099 => "\x99",
-    0x0000009a => "\x9a",
-    0x0000009b => "\x9b",
-    0x0000009c => "\x9c",
-    0x0000009d => "\x9d",
-    0x0000009e => "\x9e",
-    0x0000009f => "\x9f",
-    0x000000a0 => "\xa0",
-    0x000000a3 => "\xa3",
-    0x000000a4 => "\xa4",
-    0x000000a7 => "\xa7",
-    0x000000a8 => "\xa8",
-    0x000000ad => "\xad",
-    0x000000b0 => "\xb0",
-    0x000000b2 => "\xb2",
-    0x000000b3 => "\xb3",
-    0x000000b4 => "\xb4",
-    0x000000b5 => "\xb5",
-    0x000000b7 => "\xb7",
-    0x000000b8 => "\xb8",
-    0x000000bd => "\xbd",
-    0x000000c0 => "\xc0",
-    0x000000c1 => "\xc1",
-    0x000000c2 => "\xc2",
-    0x000000c4 => "\xc4",
-    0x000000c7 => "\xc7",
-    0x000000c8 => "\xc8",
-    0x000000c9 => "\xc9",
-    0x000000ca => "\xca",
-    0x000000cb => "\xcb",
-    0x000000cc => "\xcc",
-    0x000000cd => "\xcd",
-    0x000000ce => "\xce",
-    0x000000cf => "\xcf",
-    0x000000d1 => "\xd1",
-    0x000000d2 => "\xd2",
-    0x000000d3 => "\xd3",
-    0x000000d4 => "\xd4",
-    0x000000d6 => "\xd6",
-    0x000000d7 => "\xd7",
-    0x000000d9 => "\xd9",
-    0x000000da => "\xda",
-    0x000000db => "\xdb",
-    0x000000dc => "\xdc",
-    0x000000df => "\xdf",
-    0x000000e0 => "\xe0",
-    0x000000e1 => "\xe1",
-    0x000000e2 => "\xe2",
-    0x000000e4 => "\xe4",
-    0x000000e7 => "\xe7",
-    0x000000e8 => "\xe8",
-    0x000000e9 => "\xe9",
-    0x000000ea => "\xea",
-    0x000000eb => "\xeb",
-    0x000000ec => "\xec",
-    0x000000ed => "\xed",
-    0x000000ee => "\xee",
-    0x000000ef => "\xef",
-    0x000000f1 => "\xf1",
-    0x000000f2 => "\xf2",
-    0x000000f3 => "\xf3",
-    0x000000f4 => "\xf4",
-    0x000000f6 => "\xf6",
-    0x000000f7 => "\xf7",
-    0x000000f9 => "\xf9",
-    0x000000fa => "\xfa",
-    0x000000fb => "\xfb",
-    0x000000fc => "\xfc",
-    0x00000108 => "\xc6",
-    0x00000109 => "\xe6",
-    0x0000010a => "\xc5",
-    0x0000010b => "\xe5",
-    0x0000011c => "\xd8",
-    0x0000011d => "\xf8",
-    0x0000011e => "\xab",
-    0x0000011f => "\xbb",
-    0x00000120 => "\xd5",
-    0x00000121 => "\xf5",
-    0x00000124 => "\xa6",
-    0x00000125 => "\xb6",
-    0x00000126 => "\xa1",
-    0x00000127 => "\xb1",
-    0x00000130 => "\xa9",
-    0x00000131 => "\xb9",
-    0x00000134 => "\xac",
-    0x00000135 => "\xbc",
-    0x0000015c => "\xde",
-    0x0000015d => "\xfe",
-    0x0000015e => "\xaa",
-    0x0000015f => "\xba",
-    0x0000016c => "\xdd",
-    0x0000016d => "\xfd",
-    0x0000017b => "\xaf",
-    0x0000017c => "\xbf",
-    0x000002d8 => "\xa2",
-    0x000002d9 => "\xff",
-);
+    "\xc3\xbd",
+    "\xc3\xbe",
+    "\xc3\xbf",
+];
 
 sub _recode
 {
     if ($_[0]->{_from} eq 'INTERNAL') {
-		$_[1] = join '',
-	        map $from_ucs4{$_} 
-                || (defined $from_ucs4{$_} ? $from_ucs4{$_} : "\x3f"),
-		    @{$_[1]};
-    } elsif ($_[0]->{_to} eq 'UTF-8',) {
-		$_[1] = join '', map $to_utf8[$_], unpack 'C*', $_[1];
+		# FIXME: Maybe the lookup is cheaper than the call to chr().
+		$_[1] = join '', 
+		    map $_ > 255 ? "\x3f" : chr $_,
+			    @{$_[1]};
+    } elsif ($_[0]->{_to} eq 'UTF-8') {
+		$_[1] = join '', map TO_UTF8->[$_], unpack 'C*', $_[1];
     } else {
-		$_[1] = [ map 
-				  $to_ucs4[$_],
-				  unpack 'C*', $_[1] 
-				  ];
+		$_[1] = [ unpack 'C*', $_[1] ];
     }
 
     return 1;
@@ -820,7 +307,7 @@ __END__
 
 =head1 NAME
 
-Locale::RecodeData::ISO_8859_3 - Conversion routines for ISO-8859-3
+Locale::RecodeData::ISO_8859_1 - Conversion routines for ISO-8859-1
 
 =head1 SYNOPSIS
 
@@ -828,22 +315,7 @@ This module is internal to libintl.  Do not use directly!
 
 =head1 DESCRIPTION
 
-This module is generated and contains the conversion tables and
-routines for ISO-8859-3.
-
-=head1 COMMENTS
-
-The following comments have been extracted from the original charmap:
-
- version: 1.0
-  source: ECMA registry
- alias ISO-IR-109
- alias ISO_8859-3:1988
- alias ISO_8859-3
- alias LATIN3
- alias L3
-
-Please note that aliases listed above are not necessarily valid!
+This module contains the conversion tables and routines for ISO-8859-1.
 
 =head1 CHARACTER TABLE
 
@@ -1014,40 +486,44 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
     9E |  0000009E | PRIVACY MESSAGE (PM)
     9F |  0000009F | APPLICATION PROGRAM COMMAND (APC)
     A0 |  000000A0 | NO-BREAK SPACE
-    A1 |  00000126 | LATIN CAPITAL LETTER H WITH STROKE
-    A2 |  000002D8 | BREVE
+    A1 |  000000A1 | INVERTED EXCLAMATION MARK
+    A2 |  000000A2 | CENT SIGN
     A3 |  000000A3 | POUND SIGN
     A4 |  000000A4 | CURRENCY SIGN
-    A6 |  00000124 | LATIN CAPITAL LETTER H WITH CIRCUMFLEX
+    A5 |  000000A5 | YEN SIGN
+    A6 |  000000A6 | BROKEN BAR
     A7 |  000000A7 | SECTION SIGN
     A8 |  000000A8 | DIAERESIS
-    A9 |  00000130 | LATIN CAPITAL LETTER I WITH DOT ABOVE
-    AA |  0000015E | LATIN CAPITAL LETTER S WITH CEDILLA
-    AB |  0000011E | LATIN CAPITAL LETTER G WITH BREVE
-    AC |  00000134 | LATIN CAPITAL LETTER J WITH CIRCUMFLEX
+    A9 |  000000A9 | COPYRIGHT SIGN
+    AA |  000000AA | FEMININE ORDINAL INDICATOR
+    AB |  000000AB | LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
+    AC |  000000AC | NOT SIGN
     AD |  000000AD | SOFT HYPHEN
-    AF |  0000017B | LATIN CAPITAL LETTER Z WITH DOT ABOVE
+    AE |  000000AE | REGISTERED SIGN
+    AF |  000000AF | MACRON
     B0 |  000000B0 | DEGREE SIGN
-    B1 |  00000127 | LATIN SMALL LETTER H WITH STROKE
+    B1 |  000000B1 | PLUS-MINUS SIGN
     B2 |  000000B2 | SUPERSCRIPT TWO
     B3 |  000000B3 | SUPERSCRIPT THREE
     B4 |  000000B4 | ACUTE ACCENT
     B5 |  000000B5 | MICRO SIGN
-    B6 |  00000125 | LATIN SMALL LETTER H WITH CIRCUMFLEX
+    B6 |  000000B6 | PILCROW SIGN
     B7 |  000000B7 | MIDDLE DOT
     B8 |  000000B8 | CEDILLA
-    B9 |  00000131 | LATIN SMALL LETTER DOTLESS I
-    BA |  0000015F | LATIN SMALL LETTER S WITH CEDILLA
-    BB |  0000011F | LATIN SMALL LETTER G WITH BREVE
-    BC |  00000135 | LATIN SMALL LETTER J WITH CIRCUMFLEX
+    B9 |  000000B9 | SUPERSCRIPT ONE
+    BA |  000000BA | MASCULINE ORDINAL INDICATOR
+    BB |  000000BB | RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
+    BC |  000000BC | VULGAR FRACTION ONE QUARTER
     BD |  000000BD | VULGAR FRACTION ONE HALF
-    BF |  0000017C | LATIN SMALL LETTER Z WITH DOT ABOVE
+    BE |  000000BE | VULGAR FRACTION THREE QUARTERS
+    BF |  000000BF | INVERTED QUESTION MARK
     C0 |  000000C0 | LATIN CAPITAL LETTER A WITH GRAVE
     C1 |  000000C1 | LATIN CAPITAL LETTER A WITH ACUTE
     C2 |  000000C2 | LATIN CAPITAL LETTER A WITH CIRCUMFLEX
+    C3 |  000000C3 | LATIN CAPITAL LETTER A WITH TILDE
     C4 |  000000C4 | LATIN CAPITAL LETTER A WITH DIAERESIS
-    C5 |  0000010A | LATIN CAPITAL LETTER C WITH DOT ABOVE
-    C6 |  00000108 | LATIN CAPITAL LETTER C WITH CIRCUMFLEX
+    C5 |  000000C5 | LATIN CAPITAL LETTER A WITH RING ABOVE
+    C6 |  000000C6 | LATIN CAPITAL LETTER AE
     C7 |  000000C7 | LATIN CAPITAL LETTER C WITH CEDILLA
     C8 |  000000C8 | LATIN CAPITAL LETTER E WITH GRAVE
     C9 |  000000C9 | LATIN CAPITAL LETTER E WITH ACUTE
@@ -1057,27 +533,29 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
     CD |  000000CD | LATIN CAPITAL LETTER I WITH ACUTE
     CE |  000000CE | LATIN CAPITAL LETTER I WITH CIRCUMFLEX
     CF |  000000CF | LATIN CAPITAL LETTER I WITH DIAERESIS
+    D0 |  000000D0 | LATIN CAPITAL LETTER ETH
     D1 |  000000D1 | LATIN CAPITAL LETTER N WITH TILDE
     D2 |  000000D2 | LATIN CAPITAL LETTER O WITH GRAVE
     D3 |  000000D3 | LATIN CAPITAL LETTER O WITH ACUTE
     D4 |  000000D4 | LATIN CAPITAL LETTER O WITH CIRCUMFLEX
-    D5 |  00000120 | LATIN CAPITAL LETTER G WITH DOT ABOVE
+    D5 |  000000D5 | LATIN CAPITAL LETTER O WITH TILDE
     D6 |  000000D6 | LATIN CAPITAL LETTER O WITH DIAERESIS
     D7 |  000000D7 | MULTIPLICATION SIGN
-    D8 |  0000011C | LATIN CAPITAL LETTER G WITH CIRCUMFLEX
+    D8 |  000000D8 | LATIN CAPITAL LETTER O WITH STROKE
     D9 |  000000D9 | LATIN CAPITAL LETTER U WITH GRAVE
     DA |  000000DA | LATIN CAPITAL LETTER U WITH ACUTE
     DB |  000000DB | LATIN CAPITAL LETTER U WITH CIRCUMFLEX
     DC |  000000DC | LATIN CAPITAL LETTER U WITH DIAERESIS
-    DD |  0000016C | LATIN CAPITAL LETTER U WITH BREVE
-    DE |  0000015C | LATIN CAPITAL LETTER S WITH CIRCUMFLEX
-    DF |  000000DF | LATIN SMALL LETTER SHARP S (German)
+    DD |  000000DD | LATIN CAPITAL LETTER Y WITH ACUTE
+    DE |  000000DE | LATIN CAPITAL LETTER THORN
+    DF |  000000DF | LATIN SMALL LETTER SHARP S
     E0 |  000000E0 | LATIN SMALL LETTER A WITH GRAVE
     E1 |  000000E1 | LATIN SMALL LETTER A WITH ACUTE
     E2 |  000000E2 | LATIN SMALL LETTER A WITH CIRCUMFLEX
+    E3 |  000000E3 | LATIN SMALL LETTER A WITH TILDE
     E4 |  000000E4 | LATIN SMALL LETTER A WITH DIAERESIS
-    E5 |  0000010B | LATIN SMALL LETTER C WITH DOT ABOVE
-    E6 |  00000109 | LATIN SMALL LETTER C WITH CIRCUMFLEX
+    E5 |  000000E5 | LATIN SMALL LETTER A WITH RING ABOVE
+    E6 |  000000E6 | LATIN SMALL LETTER AE
     E7 |  000000E7 | LATIN SMALL LETTER C WITH CEDILLA
     E8 |  000000E8 | LATIN SMALL LETTER E WITH GRAVE
     E9 |  000000E9 | LATIN SMALL LETTER E WITH ACUTE
@@ -1087,22 +565,22 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
     ED |  000000ED | LATIN SMALL LETTER I WITH ACUTE
     EE |  000000EE | LATIN SMALL LETTER I WITH CIRCUMFLEX
     EF |  000000EF | LATIN SMALL LETTER I WITH DIAERESIS
+    F0 |  000000F0 | LATIN SMALL LETTER ETH
     F1 |  000000F1 | LATIN SMALL LETTER N WITH TILDE
     F2 |  000000F2 | LATIN SMALL LETTER O WITH GRAVE
     F3 |  000000F3 | LATIN SMALL LETTER O WITH ACUTE
     F4 |  000000F4 | LATIN SMALL LETTER O WITH CIRCUMFLEX
-    F5 |  00000121 | LATIN SMALL LETTER G WITH DOT ABOVE
+    F5 |  000000F5 | LATIN SMALL LETTER O WITH TILDE
     F6 |  000000F6 | LATIN SMALL LETTER O WITH DIAERESIS
     F7 |  000000F7 | DIVISION SIGN
-    F8 |  0000011D | LATIN SMALL LETTER G WITH CIRCUMFLEX
+    F8 |  000000F8 | LATIN SMALL LETTER O WITH STROKE
     F9 |  000000F9 | LATIN SMALL LETTER U WITH GRAVE
     FA |  000000FA | LATIN SMALL LETTER U WITH ACUTE
     FB |  000000FB | LATIN SMALL LETTER U WITH CIRCUMFLEX
     FC |  000000FC | LATIN SMALL LETTER U WITH DIAERESIS
-    FD |  0000016D | LATIN SMALL LETTER U WITH BREVE
-    FE |  0000015D | LATIN SMALL LETTER S WITH CIRCUMFLEX
-    FF |  000002D9 | DOT ABOVE (Mandarin Chinese light tone)
-
+    FD |  000000FD | LATIN SMALL LETTER Y WITH ACUTE
+    FE |  000000FE | LATIN SMALL LETTER THORN
+    FF |  000000FF | LATIN SMALL LETTER Y WITH DIAERESIS
 
 =head1 AUTHOR
 
